==> Assimulo-2.7b1.zip: Assimulo-2.7b1/assimulo/examples/__init__.py <==
#!/usr/bin/env python 
# -*- coding: utf-8 -*-

# Copyright (C) 2010 Modelon AB
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, version 3 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

__all__ = ["cvode_gyro", "cvode_basic", "cvode_with_disc", "cvode_with_initial_sensitivity",
           "cvode_with_jac", "cvode_with_jac_spgmr", "cvode_with_parameters", "euler_basic", "euler_with_disc",
           "rungekutta4_basic", "rungekutta34_basic", "rungekutta34_with_disc", "ida_with_disc", "ida_with_initial_sensitivity",
           "ida_with_jac", "ida_with_parameters", "radau5ode_vanderpol", "radau5ode_with_disc" , "ida_with_jac_spgmr",
           "radau5dae_vanderpol", "dopri5_basic", "dopri5_with_disc", 
           "rodasode_vanderpol", "glimda_vanderpol", "lsodar_vanderpol", "lsodar_with_disc", 
           "mech_system_pendulum", "euler_vanderpol", "cvode_with_parameters_modified",
           "cvode_basic_backward","ida_basic_backward","dasp3_basic", "cvode_with_preconditioning",
           "kinsol_basic","kinsol_with_jac", "radau5dae_time_events", "kinsol_ors", "lsodar_bouncing_ball"]

==> Assimulo-2.8.zip: Assimulo-2.8/assimulo/examples/__init__.py <==
#!/usr/bin/env python 
# -*- coding: utf-8 -*-

# Copyright (C) 2010 Modelon AB
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, version 3 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

__all__ = ["cvode_gyro", "cvode_basic", "cvode_with_disc", "cvode_with_initial_sensitivity",
           "cvode_with_jac", "cvode_with_jac_spgmr", "cvode_with_parameters", "euler_basic", "euler_with_disc",
           "rungekutta4_basic", "rungekutta34_basic", "rungekutta34_with_disc", "ida_with_disc", "ida_with_initial_sensitivity",
           "ida_with_jac", "ida_with_parameters", "radau5ode_vanderpol", "radau5ode_with_disc" , "ida_with_jac_spgmr",
           "radau5dae_vanderpol", "dopri5_basic", "dopri5_with_disc", 
           "rodasode_vanderpol", "glimda_vanderpol", "lsodar_vanderpol", "lsodar_with_disc", 
           "mech_system_pendulum", "euler_vanderpol", "cvode_with_parameters_modified",
           "cvode_basic_backward","ida_basic_backward","dasp3_basic", "cvode_with_preconditioning",
           "kinsol_basic","kinsol_with_jac", "radau5dae_time_events", "kinsol_ors", "lsodar_bouncing_ball",
           "cvode_with_parameters_fcn"]
